pytest-9.0.2
=======================================

pytest 9.0.2 has just been released to PyPI.

This is a bug-fix release, being a drop-in replacement.

The full changelog is available at https://docs.pytest.org/en/stable/changelog.html.

Thanks to all of the contributors to this release:

* Alex Waygood
* Bruno Oliveira
* Fazeel Usmani
* Freya Bruhin
* Ran Benita
* Tom Most
* 🇺🇦 Sviatoslav Sydorenko (Святослав Сидоренко)


Happy testing,
The pytest Development Team
